/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor;

import static org.ow2.util.ee.metadata.ejbjar.api.struct.ILockType.READ;
import static org.ow2.util.ee.metadata.ejbjar.api.struct.ILockType.WRITE;

import org.ow2.util.ee.metadata.common.impl.configurator.visitor.AnnotationType;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.EnumAnnotationVisitor;
import org.ow2.util.ee.metadata.ejbjar.api.ILock;


/**
 * This class manages the handling of &#64;{@link javax.ejb.TransactionAttribute} annotation.
 * @param <T> An implementation of ITransactionAttribute interface.
 * @author Florent Benoit
 */
public class JavaxEjbLockVisitor<T extends ILock>
          extends EnumAnnotationVisitor<T> implements AnnotationType {

    /**
     * Type of annotation.
     */
    public static final String TYPE = "Ljavax/ejb/Lock;";

    /**
     * Constructor.
     * @param annotationMetadata linked to a class or method metadata
     */
    public JavaxEjbLockVisitor(final T annotationMetadata) {
        super(annotationMetadata);
    }

    /**
     * Visits the end of the annotation. <br>
     * Creates the object and store it.
     */
    @Override
    public void visitEnd() {
        String s = getValue();
        // TYPE annotation
        if (getAnnotationMetadata() != null) {
            if (READ.name().equals(s)) {
                getAnnotationMetadata().setLockType(READ);
            } else if (WRITE.name().equals(s)) {
                getAnnotationMetadata().setLockType(WRITE);
            } else {
                // set default
                getAnnotationMetadata().setLockType(WRITE);
            }
        }
    }

    /**
     * @return type of the annotation (its description)
     */
    public String getType() {
        return TYPE;
    }

}
