/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.clazz;

import org.ow2.util.ee.deploy.api.deployable.EJBDeployable;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.AbsAnnotationVisitor;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarClassMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarDeployableMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarFieldMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarMethodMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.struct.IJCommonBean;
import org.ow2.util.scan.api.IType;

/**
 * This class manages the handling of common annotations used by beans.
 * @param <T> a class extending JCommonBean.
 * @param <E> an implementation of EJBDeployable
 * @param <D> an implementation of IEjbJarDeployableMetadata
 * @param <C> an implementation of IEjbJarClassMetadata
 * @param <M> an implementation of IEjbJarMethodMetadata
 * @param <F> an implementation of IEjbJarFieldMetadata
 * @author Florent Benoit
 */
public abstract class AbsCommonEjbVisitor<
    T extends IJCommonBean,
    E extends EJBDeployable<E>,
    D extends IEjbJarDeployableMetadata<E, D, C, M, F>,
    C extends IEjbJarClassMetadata<E, D, C, M, F>,
    M extends IEjbJarMethodMetadata<E, D, C, M, F>,
    F extends IEjbJarFieldMetadata<E, D, C, M, F>>
        extends AbsAnnotationVisitor<C> {

    /**
     * Name attribute of the annotation.
     */
    private static final String NAME = "name";

    /**
     * mappedName attribute of the annotation.
     */
    private static final String MAPPED_NAME = "mappedName";

    /**
     * description attribute of the annotation.
     */
    private static final String DESCRIPTION = "description";

     /**
     * Constructor.
     * @param classAnnotationMetadata linked to a class metadata
     */
    public AbsCommonEjbVisitor(final C classAnnotationMetadata) {
        super(classAnnotationMetadata);
    }

    /**
     * Visits a primitive value of the annotation.<br>
     * @param name the value name.
     * @param value the actual value, whose type must be {@link Byte},
     *        {@link Boolean}, {@link Character}, {@link Short},
     *        {@link Integer}, {@link Long}, {@link Float}, {@link Double},
     *        {@link String} or {@link IType}.
     */
    @Override
    public void visit(final String name, final Object value) {
        if (name.equals(NAME)) {
            getJCommonBean().setName((String) value);
        } else if (name.equals(MAPPED_NAME)) {
            getJCommonBean().setMappedName((String) value);
        } else if (name.equals(DESCRIPTION)) {
            getJCommonBean().setDescription((String) value);
        }
    }

    /**
     * Visits the end of the annotation. <br> Creates the object and store it.
     */
    @Override
    public void visitEnd() {
        getAnnotationMetadata().setJCommonBean(getJCommonBean());
    }

    /**
     * @return the object used by all beans.
     */
    public abstract T getJCommonBean();


}
