/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.clazz;

import static org.ow2.util.ee.metadata.ejbjar.api.struct.IConcurrencyManagementType.BEAN;
import static org.ow2.util.ee.metadata.ejbjar.api.struct.IConcurrencyManagementType.CONCURRENCY_NOT_ALLOWED;
import static org.ow2.util.ee.metadata.ejbjar.api.struct.IConcurrencyManagementType.CONTAINER;

import org.ow2.util.ee.deploy.api.deployable.EJBDeployable;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.AnnotationType;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.EnumAnnotationVisitor;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarClassMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarDeployableMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarFieldMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarMethodMetadata;


/**
 * This class manages the handling of &#64;{@link javax.ejb.ConcurrencyManagement} annotation.
 * @param <E> an implementation of EJBDeployable
 * @param <D> an implementation of IEjbJarDeployableMetadata
 * @param <C> an implementation of IEjbJarClassMetadata
 * @param <M> an implementation of IEjbJarMethodMetadata
 * @param <F> an implementation of IEjbJarFieldMetadata
 * @author Florent Benoit
 */
public class JavaxEjbConcurrencyManagementVisitor<
    E extends EJBDeployable<E>,
    D extends IEjbJarDeployableMetadata<E, D, C, M, F>,
    C extends IEjbJarClassMetadata<E, D, C, M, F>,
    M extends IEjbJarMethodMetadata<E, D, C, M, F>,
    F extends IEjbJarFieldMetadata<E, D, C, M, F>>
        extends EnumAnnotationVisitor<C> implements AnnotationType {

    /**
     * Type of annotation.
     */
    public static final String TYPE = "Ljavax/ejb/ConcurrencyManagement;";

    /**
     * Constructor.
     * @param classMetadata linked to a class metadata
     */
    public JavaxEjbConcurrencyManagementVisitor(final C classMetadata) {
        super(classMetadata);
    }

    /**
     * Visits the end of the annotation. <br>
     * Creates the object and store it.
     */
    @Override
    public void visitEnd() {
        String s = getValue();
        // TYPE annotation
        if (getAnnotationMetadata() != null) {
            if (BEAN.name().equals(s)) {
                getAnnotationMetadata().setConcurrencyManagementType(BEAN);
            } else if (CONCURRENCY_NOT_ALLOWED.name().equals(s)) {
                getAnnotationMetadata().setConcurrencyManagementType(CONCURRENCY_NOT_ALLOWED);
            } else if (CONTAINER.name().equals(s)) {
                getAnnotationMetadata().setConcurrencyManagementType(CONTAINER);
            } else {
                // set default
                getAnnotationMetadata().setConcurrencyManagementType(CONTAINER);
            }
        }
    }

    /**
     * @return type of the annotation (its description)
     */
    public String getType() {
        return TYPE;
    }

}
