/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.clazz;

import org.ow2.util.ee.deploy.api.deployable.EJBDeployable;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.AnnotationType;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.ObjectAnnotationVisitor;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarClassMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarDeployableMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarFieldMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarMethodMetadata;
import org.ow2.util.scan.api.IType;

/**
 * This class manages the handling of &#64;{@link javax.ejb.LocalHome} annotation.
 * @param <E> an implementation of EJBDeployable
 * @param <D> an implementation of IEjbJarDeployableMetadata
 * @param <C> an implementation of IEjbJarClassMetadata
 * @param <M> an implementation of IEjbJarMethodMetadata
 * @param <F> an implementation of IEjbJarFieldMetadata
 * @author Florent Benoit
 */
public class JavaxEjbLocalHomeVisitor<
    E extends EJBDeployable<E>,
    D extends IEjbJarDeployableMetadata<E, D, C, M, F>,
    C extends IEjbJarClassMetadata<E, D, C, M, F>,
    M extends IEjbJarMethodMetadata<E, D, C, M, F>,
    F extends IEjbJarFieldMetadata<E, D, C, M, F>>
        extends ObjectAnnotationVisitor<C, IType> implements AnnotationType {

    /**
     * Type of annotation.
     */
    public static final String TYPE = "Ljavax/ejb/LocalHome;";

    /**
     * Constructor.
     * @param classAnnotationMetadata linked to a class metadata
     */
    public JavaxEjbLocalHomeVisitor(final C classAnnotationMetadata) {
        super(classAnnotationMetadata);
    }

    /**
     * Visits the end of the annotation.<br> Creates the object and store it.
     */
    @Override
    public void visitEnd() {
        IType t = getValue();
        String className = t.getInternalName();
        getAnnotationMetadata().setLocalHome(className);
    }

    /**
     * @return type of the annotation (its description).
     */
    public String getType() {
        return TYPE;
    }

}
