/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.method;

import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarMethodMetadata;
import org.ow2.util.ee.metadata.ejbjar.impl.struct.JEJBSchedule;
import org.ow2.util.scan.api.IType;

/**
 * This class manages the handling of &#64;{@link javax.ejb.Schedules} annotation.
 * @author Florent Benoit
 */
public class JavaxEjbSchedulesVisitor extends JavaxEjbScheduleVisitor<IEjbJarMethodMetadata<?, ?, ?, ?, ?>> {

    /**
     * Type of annotation.
     */
    public static final String TYPE = "Ljavax/ejb/Schedules;";

    /**
     * Object is added to the list.
     */
    private boolean isAdded = false;

    /**
     * Constructor.
     * @param annotationMetadata linked to a method metadata
     */
    public JavaxEjbSchedulesVisitor(final IEjbJarMethodMetadata<?, ?, ?, ?, ?> annotationMetadata) {
        super(annotationMetadata);
    }

    /**
     * Visits a primitive value of the annotation.<br>
     * @param name the value name.
     * @param value the actual value, whose type must be {@link Byte},
     *        {@link Boolean}, {@link Character}, {@link Short},
     *        {@link Integer}, {@link Long}, {@link Float}, {@link Double},
     *        {@link String} or {@link org.ow2.util.scan.api.IType}.
     */
    @Override
    public void visit(final String name, final Object value) {
        if (isAdded) {
            setJEJBSchedule(new JEJBSchedule());
            isAdded = false;
        }

        // do super code
        super.visit(name, value);
    }

    /**
     * Visits the end of the annotation. <br>
     * Creates the object and store it.
     */
    @Override
    public void visitEnd() {
        // add object in the list
        if (!isAdded) {
            getAnnotationMetadata().addJavaxEjbSchedule(getJEJBSchedule());
            isAdded = true;
        }

    }

    /**
     * @return type of the annotation (its description)
     */
    @Override
    public String getType() {
        return TYPE;
    }

}
