/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.internal;

import org.ow2.util.ee.deploy.api.deployable.EJBDeployable;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.EjbJarClassMetadataConfigurator;
import org.ow2.util.scan.api.configurator.IFieldConfigurator;
import org.ow2.util.scan.api.configurator.IMethodConfigurator;
import org.ow2.util.scan.api.metadata.structures.JField;
import org.ow2.util.scan.api.metadata.structures.JMethod;

/**
 * Default configurator.
 * @param <E> an implementation of EJBDeployable
 * @author Florent Benoit
 */
public class DefaultEjbJarClassMetadataConfigurator<E extends EJBDeployable<E>>
        extends
        EjbJarClassMetadataConfigurator<E, DefaultEjbJarDeployableMetadata<E>, DefaultEjbJarClassMetadata<E>, DefaultEjbJarMethodMetadata<E>, DefaultEjbJarFieldMetadata<E>> {

    public DefaultEjbJarClassMetadataConfigurator(final DefaultEjbJarClassMetadata<E> classMetadata,
            final DefaultEjbJarDeployableMetadata<E> ejbJarArchiveMetadata, final boolean annotationParsingDesactived) {
        super(classMetadata, ejbJarArchiveMetadata, annotationParsingDesactived);
    }

    @Override
    protected IFieldConfigurator createFieldMetadataConfigurator(final JField field,
            final DefaultEjbJarClassMetadata<E> classMetadata, final boolean annotationParsingDesactived) {
        DefaultEjbJarFieldMetadata<E> fieldMetadata = new DefaultEjbJarFieldMetadata<E>(field, classMetadata);
        return new DefaultEjbJarFieldMetadataConfigurator<E>(fieldMetadata, annotationParsingDesactived);
    }

    @Override
    protected IMethodConfigurator createMethodMetadataConfigurator(final JMethod method,
            final DefaultEjbJarClassMetadata<E> classMetadata, final boolean annotationParsingDesactived) {
        DefaultEjbJarMethodMetadata<E> methodMetadata = new DefaultEjbJarMethodMetadata<E>(method, classMetadata);
        return new DefaultEjbJarMethodMetadataConfigurator<E>(methodMetadata, annotationParsingDesactived);
    }

}
