/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.internal;

import org.ow2.util.ee.deploy.api.deployable.EJBDeployable;
import org.ow2.util.ee.metadata.ejbjar.impl.configurator.EjbJarDeployableMetadataConfigurator;
import org.ow2.util.scan.api.configurator.IClassConfigurator;
import org.ow2.util.scan.api.metadata.structures.JClass;

/**
 * Default configurator.
 * @param <E> an implementation of EJBDeployable
 * @author Florent Benoit
 */
public class DefaultEjbJarDeployableMetadataConfigurator<E extends EJBDeployable<E>>
        extends
        EjbJarDeployableMetadataConfigurator<E, DefaultEjbJarDeployableMetadata<E>, DefaultEjbJarClassMetadata<E>, DefaultEjbJarMethodMetadata<E>, DefaultEjbJarFieldMetadata<E>> {

    public DefaultEjbJarDeployableMetadataConfigurator(final DefaultEjbJarDeployableMetadata<E> ejbJarArchiveMetadata) {
        super(ejbJarArchiveMetadata);
    }

    @Override
    protected DefaultEjbJarClassMetadata<E> createClassMetadata(final JClass jClass,
            final DefaultEjbJarDeployableMetadata<E> ejbJarArchiveMetadata) {
        DefaultEjbJarClassMetadata<E> classMetadata = new DefaultEjbJarClassMetadata<E>();
        classMetadata.setJClass(jClass);
        classMetadata.setEjbJarArchiveMetadata(ejbJarArchiveMetadata);
        return classMetadata;
    }

    @Override
    protected IClassConfigurator createClassMetadataConfigurator(final DefaultEjbJarClassMetadata<E> classMetadata,
            final DefaultEjbJarDeployableMetadata<E> ejbJarArchiveMetadata, final boolean annotationParsingDesactived) {
        return new DefaultEjbJarClassMetadataConfigurator<E>(classMetadata, ejbJarArchiveMetadata, annotationParsingDesactived);
    }


}
