/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ejbjar.impl.xml.helper;

import java.util.Collection;

import org.ow2.util.ee.deploy.api.deployable.EJBDeployable;
import org.ow2.util.ee.metadata.common.api.ICommonClassMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonFieldMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonMethodMetadata;
import org.ow2.util.ee.metadata.common.api.interfaces.IEnvironmentRefAccessor;
import org.ow2.util.ee.metadata.common.impl.xml.merge.MetadataMerge;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarClassMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarDeployableMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarFieldMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarMethodMetadata;

/**
 * Defines common stuff that can be used by merger of Deployment Descriptor into
 * the metadata.
 * @param <E> an implementation of EJBDeployable
 * @param <D> an implementation of IEjbJarDeployableMetadata
 * @param <C> an implementation of IEjbJarClassMetadata
 * @param <M> an implementation of IEjbJarMethodMetadata
 * @param <F> an implementation of IEjbJarFieldMetadata
 * @author Florent BENOIT
 */
public class CommonMetadataMerge<
    E extends EJBDeployable<E>,
    D extends IEjbJarDeployableMetadata<E, D, C, M, F>,
    C extends IEjbJarClassMetadata<E, D, C, M, F>,
    M extends IEjbJarMethodMetadata<E, D, C, M, F>,
    F extends IEjbJarFieldMetadata<E, D, C, M, F>> extends MetadataMerge {

    /**
     * Metadata for an ejb-jar.
     */
    private D ejbMetadata = null;

    /**
     * Logger.
     */
    //private static Log logger = LogFactory.getLog(CommonMetadataMerge.class);

    /**
     * Constructor that can be used by subclass.
     * @param ejbMetadata the metadata corresponding to an EJB-JAR file.
     */
    protected CommonMetadataMerge(final D ejbMetadata) {
        this.ejbMetadata = ejbMetadata;
    }

    /**
     * @return the EJB metadata of this merger.
     */
    public D getEjbJarDeployableMetadata() {
        return ejbMetadata;
    }

    @Override
    public String findDefaultClassForEnvironment(final IEnvironmentRefAccessor env) {
        return null;
    }

    @Override
    public ICommonClassMetadata<?, ?, ?> getClassMetadata(final String className) {
        return ejbMetadata.getScannedClassMetadata(className);
    }

    /**
     * @return A collection of all ClassMetadata of the merged object.
     */
    protected Collection<? extends ICommonClassMetadata> getAllClassMetadatas() {
        throw new UnsupportedOperationException("EjbJar does not supports metadata browsing.");
    }

    /**
     * @return A collection of all MethodMetadata of the merged object.
     */
    protected Collection<? extends ICommonMethodMetadata> getAllMethodMetadatas() {
        throw new UnsupportedOperationException("EjbJar does not supports metadata browsing.");
    }

    /**
     * @return A collection of all FieldMetadata of the merged object.
     */
    protected Collection<? extends ICommonFieldMetadata> getAllFieldMetadatas() {
        throw new UnsupportedOperationException("EjbJar does not supports metadata browsing.");
    }


}
